@@ -9,7 +9,10 @@ HERE = Path(__file__).parent.resolve()
 def _run_tool(tool_name: str) -> None:
     tool_path = HERE / "tools" / tool_name
     env = os.environ.copy()
-    subprocess.run([str(tool_path)] + sys.argv[1:], check=True, env=env)
+    try:
+        subprocess.run([str(tool_path)] + sys.argv[1:], check=True, env=env)
+    except subprocess.CalledProcessError as e:
+        print(f"Error: {tool_name} failed with return code {e.returncode}.")
 
 
 def ocioarchive() -> None:
